#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   dbus-menu
version:                0.1.3.4
visibility:             public
id:                     dbus-menu-0.1.3.4-14jG7ciHHl2JA87iylfQUt
key:                    dbus-menu-0.1.3.4-14jG7ciHHl2JA87iylfQUt
license:                BSD-3-Clause
copyright:              2018 Ivan Malison
maintainer:             IvanMalison@gmail.com
author:                 Ivan Malison
homepage:               https://github.com/taffybar/dbus-menu#readme
synopsis:               A Haskell implementation of the DBusMenu protocol
description:
    Haskell client for the com.canonical.dbusmenu DBus interface, providing GTK3 menu construction from DBusMenu services.

category:               System
abi:                    6d4cfecc9a8c7b3700e17f72891f2eae
exposed:                True
exposed-modules:
    DBusMenu DBusMenu.Client DBusMenu.Client.Util DBusMenu.Reconcile

hidden-modules:         Paths_dbus_menu
import-dirs:            /usr/lib/ghc-9.6.6/site-local/dbus-menu-0.1.3.4
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/dbus-menu-0.1.3.4 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/dbus-menu-0.1.3.4 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-dbus-menu
hs-libraries:           HSdbus-menu-0.1.3.4-14jG7ciHHl2JA87iylfQUt
extra-libraries:
    gtk-3 gdk-3 pangocairo-1.0 cairo-gobject gdk_pixbuf-2.0 atk-1.0
    pango-1.0 cairo harfbuzz gio-2.0 gobject-2.0 glib-2.0 z

extra-libraries-static:
    gtk-3 gdk-3 pangocairo-1.0 Xrandr Xcursor Xcomposite Xdamage
    Xinerama cloudproviders cairo-gobject m dl gdk_pixbuf-2.0 m
    glycin-2 seccomp lcms2 m pthread atk-bridge-2.0 atspi Xtst Xi
    Xfixes atk-1.0 dbus-1 xkbcommon wayland-cursor wayland-egl
    wayland-client m rt epoxy dl GL EGL pangoft2-1.0 m pango-1.0 m
    fribidi thai datrie Xft cairo m dl fontconfig m expat m Xext
    Xrender X11 pthread xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m
    harfbuzz-gobject harfbuzz m freetype dl bz2 png16 m m brotlidec
    brotlicommon graphite2 gio-2.0 gobject-2.0 ffi gmodule-2.0 glib-2.0
    atomic m pcre2-8 pthread z mount blkid systemd sysprof-capture-4

include-dirs:
    /usr/include/gtk-3.0 /usr/include/pango-1.0 /usr/include
    /usr/include/cloudproviders /usr/include/cairo
    /usr/include/gdk-pixbuf-2.0 /usr/include/glycin-2
    /usr/include/at-spi2-atk/2.0 /usr/include/at-spi-2.0
    /usr/include/atk-1.0 /usr/include/dbus-1.0
    /usr/lib/dbus-1.0/include /usr/include/fribidi
    /usr/include/pixman-1 /usr/include/harfbuzz /usr/include/freetype2
    /usr/include/libpng16 /usr/include/gio-unix-2.0
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/sysprof-6

depends:
    base-4.18.2.1 containers-0.6.7 dbus-1.3.3-9OEqjIVZ3OOBkubOeWApON
    enclosed-exceptions-1.0.3-JAMZ7NJniZq89V58ZtPXFY filepath-1.4.300.1
    gi-glib-2.0.30-IbMceUkbPFbAzdIeE6ROJx
    gi-gobject-2.0.31-98nt0liAWOGCQ6jtwFHBqO
    gi-gtk3-3.0.44-Gcb1dlYBmE7F0cSj3v1EBY
    haskell-gi-0.26.17-8JFBf5L4fuwFdV2u3KLSL6
    haskell-gi-base-0.26.9-A51M6LjdiVN4RjdHJdLeji
    hslogger-1.3.2.0-5J7cXR4zP7qIvFH1YUzyfL template-haskell-2.20.0.0
    text-2.0.2

haddock-interfaces:     /usr/share/doc/haskell-dbus-menu/html/dbus-menu.haddock
haddock-html:           /usr/share/doc/haskell-dbus-menu/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

